<?php
require_once 'Query.php';
class Page {
    /**
     * template directory
     * 
     * @var string
     */
    protected $_templateDirectory;
    /**
     * template suffix
     *
     * @var string
     */
    protected $_templateSuffix = '.html';
    /**
     * query
     *
     * @var Query
     */
    protected $_query;
    /**
     * injection object
     *
     * @var mixed
     */
    protected $_obj;
    /**
     * tempalte name
     *
     * @var string
     */
    private $_templateName;
    /**
     * Constructor
     *
     * @param mixed
     */
    public function __construct($obj) {
        $this->_loadTemplate();
        $this->_obj = $obj;
        $this->_injection();
    }
    /**
     * set template directory
     *
     * @param string $dir
     */
    public function setTemplateDirectory($dir) {
        $this->_templateDirectory = $dir;
    }
    /**
     * set template suffix
     * 
     * @param string $suffix
     */
    public function setTemplateSuffix($suffix) {
        $this->_templateSuffix = $suffix;
    }
    /**
     * get DomDocument
     *
     * @return DOMDocument
     */
    public function getDom() {
        return $this->_query->getDom();
    }
    /**
     * load template
     * 
     * @return void
     */
    private function _loadTemplate() {
        $this->_templateName = strtolower(get_class($this));
        $template = $this->_templateDirectory .
                $this->_templateName .
                $this->_templateSuffix;
        if (!file_exists($template)) {
            throw new Exception("template $template not found.");
        }
        $dom = new DOMDocument();
        $dom->formatOutput = true;
        ob_start();
        include $template;
        $dom->loadHTML(ob_get_contents());
        ob_end_clean();
        $this->_query = new Query($dom);
    }
    /**
     * injection
     * 
     * @return void
     */
    private function _injection() {
        $obj = new ReflectionClass($this);
        $methods = $obj->getMethods(ReflectionMethod::IS_PUBLIC);
        foreach ($methods as $method) {
            if (strtolower($method->class) !== 'page'
                    && substr($method->name, 0, 1) !== '_'
                    && !in_array($method->name, get_class_methods(get_class())))  {
                $method->invoke($this);
            }
        }

    }
}
?>
